/*
 * Copyright (C) 2012 Andre Noll <maan@tuebingen.mpg.de>
 *
 * Licensed under the GPL v2. For licencing details see COPYING.
 */

/** \file check_wav.h Detect, process and cut a wav header. */

struct check_wav_context;

/**
 * These come from the command line arguments.
 *
 * Different users of the check_wav API have different arg_info structs,
 * so we need a universal variant for these.
 */
struct wav_params {
	/** Number of channels, or the default value. */
	int channels_arg;
	/** Whether the channel count was given. */
	int channels_given;
	/** Same semantics as \a channels_count. */
	int sample_rate_arg;
	/** Whether the sample rate was given. */
	int sample_rate_given;
	/** Same semantics as \a sample_rate. */
	int sample_format_arg;
	/** Whether the sample format was given. */
	int sample_format_given;
};

/**
 * Copy the wav parameters.
 *
 * \param dst Usually a pointer to struct wav_params.
 * \param src Usually a pointer to some args_info struct.
 *
 * This can not be implemented as a function since the type of the structure
 * pointed to by \a src depends on the application.
 */
#define COPY_WAV_PARMS(dst, src) \
	(dst)->channels_arg = (src)->channels_arg; \
	(dst)->channels_given = (src)->channels_given; \
	(dst)->sample_rate_arg = (src)->sample_rate_arg; \
	(dst)->sample_rate_given = (src)->sample_rate_given; \
	(dst)->sample_format_arg = (src)->sample_format_arg; \
	(dst)->sample_format_given = (src)->sample_format_given;

struct check_wav_context *check_wav_init(struct btr_node *parent,
		struct btr_node *child, struct wav_params *params,
		struct btr_node **cw_btrn);
void check_wav_pre_select(struct sched *s, struct check_wav_context *cwc);
int check_wav_post_select(struct check_wav_context *cwc);
void check_wav_shutdown(struct check_wav_context *cwc);
